#!/bin/bash
DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
INSTALLDIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )"/../.. && pwd )"
OS="debian"
if [ -d /etc/yum ] 
then
    OS="centos"
fi
echo System: $OS


function installIoncube() {
  echo " Installing ioncube"
  cd /tmp
  wget https://downloads.ioncube.com/loader_downloads/ioncube_loaders_lin_x86-64.zip
  unzip ioncube_loaders_lin_x86-64.zip
  cd ioncube
  mkdir -p /usr/lib64/php/modules/

  if [ "$OS" == "centos" ]
  then
    cp ioncube_loader_lin_5.4.so /usr/lib64/php/modules/
    phpCLIConfigDir=""
    cat > /etc/php.d/00-ioncube.ini <<-EOF
    zend_extension = /usr/lib64/php/modules/ioncube_loader_lin_5.4.so
EOF
  else
    cp ioncube_loader_lin_7.4.so /usr/lib64/php/modules/
    cat > /etc/php/7.4/cli/conf.d/00-ioncube.ini <<-EOF
    zend_extension = /usr/lib64/php/modules/ioncube_loader_lin_7.4.so
EOF
  fi

  rm -f ioncube_loaders_lin_x86-64.zip
  rm -rf ioncube
}

launcher="/bin/bash"
if [ ! -f /bin/bash ]
then
  launcher="/bin/sh"
fi

launcherphp="/bin/php"
if [ -f /usr/bin/php ]
then
  launcherphp="/usr/bin/php"
fi

ioncube=`$launcherphp -v | grep -i ioncube | wc -l`
if [ "$ioncube" = "0" ]
then
  installIoncube
fi



cat > /etc/cron.d/radmin <<EOF
PATH=/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/bin:/sbin:/root/bin
#0 2 * * * root systemctl restart radmin
*/1 * * * * root $launcherphp $INSTALLDIR/sendstats.php > /dev/null
EOF

cat > /etc/cron.d/radmin-backup <<EOF
PATH=/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/bin:/sbin:/root/bin
* * * * * root $launcherphp $INSTALLDIR/sendbackup.php > /dev/null
EOF

if [ $OS = "centos" ]
then
  systemctl restart crond
else
  systemctl restart cron
fi


mkdir -p /etc/radmin
/usr/bin/php $DIR/update.php
if [ $? -eq 0 ]
then
  if [ -f /etc/radmin/config_client.php.old ]
  then
    rm -rf /etc/radmin/config_client.php.old
  fi
else
  echo "***ERROR: failed to update configuration file !"
  exit 1
fi

if [ -d /usr/share/ombutel ]
then
  ln -s $INSTALLDIR/gui /usr/share/ombutel/www/radmin
  if [ $OS = "centos" ]
  then
    chown root:apache /etc/radmin/config.json
  else
    chown root:www-data /etc/radmin/config.json
  fi
  chmod 664 /etc/radmin/config.json
fi

#Update service file.
if [ -f /etc/init.d/radmin ]
then
  systemctl disable radmin
  systemctl stop radmin
  rm -rf /etc/init.d/radmin
fi
systemctl daemon-reload

cat > /etc/systemd/system/radmin.service <<-EOF
[Unit]
Description=Radmin client
Documentation=
Wants=network-online.target
After=

[Service]
User=root
Type=simple
ExecStart=$launcherphp /usr/local/radmin/radmin.php > /dev/null
ExecStop=/usr/bin/sudo killall ssh -v -s 9; /usr/bin/sudo killall autossh -v -s 9
Restart=on-failure
RestartSec=5
WorkingDirectory=/usr/local/radmin
KillMode=control-group
KillSignal=SIGKILL

[Install]
WantedBy=multi-user.target
EOF
systemctl daemon-reload
systemctl enable radmin
systemctl restart radmin

# on CPBX, add the menu. on servers without cpbx, no menu will be added.
if [ -d /usr/share/ombutel ]
then
  php $DIR/InstallAPIKeyOmbutel.php
fi

exit 0